@@ -14,9 +14,7 @@
     :license: MIT, see LICENSE for more details.
 """
 
-__version__ = '0.2'
-
-import os
+__version__ = '0.3'
 
 from . import loader
 kl = loader.LazyKaylee()
@@ -36,13 +34,13 @@ from .errors import (KayleeError,
                      ApplicationCompletedError,)
 
 
-def setup(config):
+def setup(settings):
     #pylint: disable-msg=W0212
     #W0212: Access to a protected member _setup
-    if config is not None:
-        # In this case we are trying to load Kaylee from the given config
-        kl._setup(loader.load(config))
+    if settings is not None:
+        # In this case we are trying to load Kaylee from the given settings
+        kl._setup(loader.load(settings))
     else:
-        # In this case the user probably(!) asks us to "release" Kaylee
+        # In this case the user asks us to "release" Kaylee
         # instance from the proxy.
         kl._setup(None)
