@@ -1,13 +1,25 @@
 # -*- coding: utf-8 -*-
+"""
+    kaylee.contrib.controllers
+    ~~~~~~~~~~~~~~~~~~~~~~~~~~
+
+    The module provides basic Kaylee controller implementations.
+
+    :copyright: (c) 2013 by Zaur Nasibov.
+    :license: MIT, see LICENSE for more details.
+"""
 from kaylee.controller import Controller, NO_SOLUTION, NOT_SOLVED
-from kaylee.errors import ApplicationCompletedError, NodeRequestRejectedError
+from kaylee.errors import (ApplicationCompletedError,
+                           NodeRequestRejectedError,
+                           NoneResultAssertError,)
+
 
 class SimpleController(Controller):
     """
     This is a very basic controller which serves the tasks by
-    Node requests and passes the accepted results directly to the project.
+    node requests and passes the accepted results directly to the project.
     Its ``completed`` indicator is set to ``True`` the moment the bound
-    project is completed. The controller doesn't use temporal storage.
+    project is completed. The controller doesn't use a temporal storage.
     """
     def __init__(self, *args, **kwargs):
         super(SimpleController, self).__init__(*args, **kwargs)
@@ -39,6 +51,9 @@ class SimpleController(Controller):
             return
 
         norm_result = self.project.normalize_result(node.task_id, result)
+        if norm_result is None:
+            raise NoneResultAssertError(result)
+
         self.store_result(node.task_id, norm_result)
         self._tasks_pool.remove(node.task_id)
         if self.project.completed:
@@ -49,7 +64,7 @@ class SimpleController(Controller):
 class ResultsComparatorController(Controller):
     """
     This controller is a simple implementation of the "trust no one" idea.
-    The intermediate results are collected in the temporal storage until
+    The intermediate results are collected in a temporal storage until
     their number reaches a user-defined limit. Then the results are pairly
     compared and only if they all match among themselves, a single result
     is stored inside the permanent storage. The results are discarded if they
@@ -59,8 +74,8 @@ class ResultsComparatorController(Controller):
                                     before running the comparison routine.
     """
     def __init__(self, *args, **kwargs):
+        self._results_count_threshold = kwargs.pop('results_count_threshold')
         super(ResultsComparatorController, self).__init__(*args, **kwargs)
-        self._results_count_threshold = kwargs['results_count_threshold']
         self._tasks_pool = set()
 
     def get_task(self, node):
@@ -79,7 +94,7 @@ class ResultsComparatorController(Controller):
         node.task_id = task_id
         self._tasks_pool.add(task_id)
 
-        if node.id in self.temporal_storage[task_id]:
+        if self.temporal_storage.contains(task_id, node.id):
             raise NodeRequestRejectedError('The result of this task has been '
                                            'already accepted.')
         return task
@@ -94,6 +109,8 @@ class ResultsComparatorController(Controller):
             norm_result = result
         else:
             norm_result = self.project.normalize_result(task_id, result)
+            if norm_result is None:
+                raise NoneResultAssertError(result)
 
         # 'results' computed for the task by various nodes
         tmp_results = self.temporal_storage[task_id]
@@ -113,7 +130,7 @@ class ResultsComparatorController(Controller):
                     self._tasks_pool.remove(task_id)
             node.task_id = None
         else:
-            self.temporal_storage.add(node.id, task_id, norm_result)
+            self.temporal_storage.add(task_id, node.id, norm_result)
 
     @staticmethod
     def _results_are_equal(r0, res):
