@@ -20,8 +20,10 @@ from contextlib import closing
 from functools import wraps
 
 from .node import Node, NodeID
-from .errors import KayleeError, InvalidResultError, NodeRequestRejectedError
+from .errors import (KayleeError, InvalidResultError, NodeRequestRejectedError,
+                     InvalidConfigurationError)
 from .controller import KL_RESULT
+from .util import DictAsObjectWrapper
 
 log = logging.getLogger(__name__)
 
@@ -45,16 +47,15 @@ def json_error_handler(f):
             return f(*args, **kwargs)
         except Exception as e:
             exc_str = str(e)
-
             if log.getEffectiveLevel() == logging.DEBUG:
                 with closing(StringIO()) as buf:
                     # exc_type, exc_value, exc_traceback = sys.exc_info()
                     exc_traceback = sys.exc_info()[2]
                     traceback.print_tb(exc_traceback,
-                                       limit = None,
-                                       file = buf)
+                                       limit= None,
+                                       file= buf)
                     exc_str += '\n' + buf.getvalue()
-            return json.dumps({ 'error' : exc_str })
+            return json.dumps({'error': exc_str })
 
     return wrapper
 
@@ -73,7 +74,7 @@ class Kaylee(object):
     :param registry: active nodes registry
     :param session_data_manager: global session data manager
     :param applications: a list of applications (:class:`Controller` objects)
-    :param kwargs: Kaylee configuration arguments.
+    :param \**kwargs: Kaylee configuration arguments.
     :type registry: :class:`NodesRegistry`
     :type session_data_manager: :class:`SessionDataManager` or None
     :type applications: list or None
@@ -81,10 +82,10 @@ class Kaylee(object):
     def __init__(self, registry, session_data_manager = None,
                  applications = None, **kwargs):
         #: An internal configuration storage object which maintains
-        #: the configuration initially parsed from ``**kwargs**``.
+        #: the configuration initially parsed from ``**kwargs``.
         #: The options are accessed as object attributes, e.g.:
-        #: ``kl.config.WORKER_SCRIPT_URL``.
-        self._config = Config(**kwargs)
+        #: ``kl.config.SECRET_KEY``.
+        self.config = Config(**kwargs)
 
         #: Active nodes registry (an instance of :class:`NodesRegistry`).
         self.registry = registry
@@ -95,13 +96,16 @@ class Kaylee(object):
         else:
             self._applications = Applications.empty()
 
+        log.info(str(self._applications))
+
+
     @json_error_handler
     def register(self, remote_host):
         """Registers the remote host (browser) as Kaylee Node and returns
         JSON-formatted data with the following fields:
 
         * node_id - node id (hex-formatted string)
-        * config  - client configuration (see :ref:`configuration`).
+        * config  - client configuration (see :ref:`settings`).
         * applications - a list of Kaylee applications' names.
 
         :param remote_host: the IP address of the remote host
@@ -110,7 +114,7 @@ class Kaylee(object):
         node = Node(NodeID.for_host(remote_host))
         self.registry.add(node)
         return json.dumps ({ 'node_id' : str(node.id),
-                             'config' : self._config.to_dict(),
+                             'config' : self.config.to_client_dict(),
                              'applications' : self._applications.names } )
 
     @json_error_handler
@@ -146,7 +150,8 @@ class Kaylee(object):
             client_config = node.subscribe(app)
             return json.dumps(client_config)
         except KeyError:
-            raise KayleeError('Application "{}" was not found'.format(app))
+            raise KayleeError('Application "{}" was not found'
+                              .format(application))
 
     @json_error_handler
     def unsubscribe(self, node_id):
@@ -157,14 +162,14 @@ class Kaylee(object):
         """
         self.registry[node_id].unsubscribe()
 
-    @json_error_handler
+#    @json_error_handler
     def get_action(self, node_id):
         """Returns an action (usually a task from the subscribed application).
         The format of the JSON response is::
 
           {
-              'action' : <action>,
-              'data'   : <data>
+              'action': <action>,
+              'data': <data>
           }
 
         Here, <action> tells the Node, what should it do and <data> is
@@ -224,7 +229,8 @@ class Kaylee(object):
             self.unsubscribe(node)
             raise e
 
-        if self._config.AUTO_GET_ACTION:
+        #pylint: disable-msg=E1101
+        if self.config.AUTO_GET_ACTION:
             return self.get_action(node.id)
         return self._json_action(ACTION_NOP)
 
@@ -252,29 +258,27 @@ class Kaylee(object):
         return json.dumps( { 'action' : action, 'data' : data } )
 
 
-class Config(object):
+class Config(DictAsObjectWrapper):
     """The ``Config`` object maintains the run-time Kaylee
     configuration options (see :ref:`configuration` for full description).
     """
-    serialized_attributes = [
+    client_config_fields = [
         'AUTO_GET_ACTION',
-        'WORKER_SCRIPT_URL',
     ]
 
     def __init__(self, **kwargs):
+        super(Config, self).__init__(**kwargs)
         self._dirty = True
         self._cached_dict = {}
+        self._validate()
 
-        # first, set the options with default values
-        self.AUTO_GET_ACTION = kwargs.get('AUTO_GET_ACTION', True)
-        self.SECRET_KEY = kwargs.get('SECRET_KEY', None)
-
-        # next, set the options with required values
-        try:
-            self.WORKER_SCRIPT_URL = kwargs.get('WORKER_SCRIPT_URL', None)
-        except KeyError as e:
-            raise KeyError('The required config option is missing: {}'
-                           .format(e.args[0]))
+    def _validate(self):
+        #pylint: disable-msg=E1101
+        if not isinstance(self.AUTO_GET_ACTION, bool):
+            raise InvalidConfigurationError('AUTO_GET_ACTION is not a boolean')
+        #pylint: disable-msg=E1101
+        if not isinstance(self.SECRET_KEY, basestring):
+            raise InvalidConfigurationError('SECRET_KEY is not a string object')
 
     def __setattr__(self, name, value):
         if name != '_dirty':
@@ -283,10 +287,10 @@ class Config(object):
         else:
             self.__dict__[name] = value
 
-    def to_dict(self):
+    def to_client_dict(self):
         if self._dirty:
             self._cached_dict = { k : getattr(self, k)
-                                  for k in self.serialized_attributes }
+                                  for k in self.client_config_fields }
             self._dirty = False
         return self._cached_dict
 
@@ -317,6 +321,13 @@ class Applications(object):
         """Returns the amount of applications in the container."""
         return len(self._controllers)
 
+    def __str__(self):
+        s = 'Kaylee applications({}): '.format(len(self))
+        s += '[{}]'.format(', '.join(cname for cname in self._controllers))
+        return s
+
+
+
     @staticmethod
     def empty():
         return Applications([])
