@@ -76,7 +76,7 @@ class Node(object):
         if self.controller.completed:
             raise ApplicationCompletedError(self.controller)
         task = self.controller.get_task(self)
-        task['id'] = str(task['id'])
+        task['id'] = str(task['id']).strip()
         return task
 
     def accept_result(self, result):
@@ -151,15 +151,15 @@ class NodeID(object):
     Another useful conversion is::
 
         n1 = NodeID()
-        n2 = NodeID( str(NodeID) )
+        n2 = NodeID(str(NodeID))
         n1 == n2
         # >>> True
 
     The NodeID object can be also effectively used as a key in collections::
 
         n1 = NodeID()
-        d = { n1: 'some_val' }
-        n2 = NodeID( str(NodeID) )
+        d = {n1: 'some_val'}
+        n2 = NodeID(str(NodeID))
         n2 in d
         # >>> True
 
@@ -178,7 +178,7 @@ class NodeID(object):
     _inc = 0
     _inc_lock = threading.Lock()
 
-    def __init__(self, node_id = None, remote_host = '127.0.0.1'):
+    def __init__(self, node_id=None, remote_host='127.0.0.1'):
         if node_id is None and not isinstance(remote_host, basestring):
             raise TypeError('remote_host must be an instance of {}, not {}'
                             .format(basestring.__name__,
@@ -198,35 +198,11 @@ class NodeID(object):
         :type host: string
         :returns: NodeID object
         """
-        return NodeID(remote_host = host)
+        return NodeID(remote_host=host)
 
-    @staticmethod
-    def from_object(node):
-        """Extracts or constructs NodeID from the given object.
-
-        :param node: a valid NodeID or previously initialized Kaylee Node
-                     object.
-        :type node: string, NodeID or :class:`Node`
-        :returns: NodeID object
-        """
-        if isinstance(node, basestring):
-            return NodeID(node_id = node)
-        elif isinstance(node, NodeID):
-            return node
-        elif isinstance(node, Node):
-            return NodeID(node_id = node.id)
-        else:
-            raise TypeError('node must be an instance of {}, {}, or {} not'
-                            ' {}'.format(basestring.__name__,
-                                         NodeID.__name__,
-                                         Node.__name__,
-                                         type(node).__name__))
 
     def _generate(self, remote_host):
         """Generates a new value for this NodeID."""
-        #pylint: disable-msg=E1101
-        #E1101: Module 'hashlib' has no 'md5' member # FALSE ALARM
-        ###
         nid = b''
         # 4 bytes current time
         nid += struct.pack('>i', int(time.time()))
@@ -235,6 +211,8 @@ class NodeID(object):
             nid += struct.pack(">i", NodeID._inc)[2:4]
             NodeID._inc = (NodeID._inc + 1) % 0xFFFF
         # 4 bytes host
+        #pylint: disable-msg=E1101
+        #E1101: Instance of 'md5' has no 'update' member
         host_hash = hashlib.md5()
         host_hash.update(remote_host)
         nid += host_hash.digest()[0:4]
@@ -288,27 +266,27 @@ class NodeID(object):
         return "NodeID('{}')".format(str(self))
 
     def __eq__(self, other):
-        other = NodeID.from_object(other)
+        other = NodeID(other)
         return self._id == other._id
 
     def __ne__(self, other):
-        other = NodeID.from_object(other)
+        other = NodeID(other)
         return self._id != other._id
 
     def __lt__(self, other):
-        other = NodeID.from_object(other)
+        other = NodeID(other)
         return self._id < other._id
 
     def __le__(self, other):
-        other = NodeID.from_object(other)
+        other = NodeID(other)
         return self._id <= other._id
 
     def __gt__(self, other):
-        other = NodeID.from_object(other)
+        other = NodeID(other)
         return self._id > other._id
 
     def __ge__(self, other):
-        other = NodeID.from_object(other)
+        other = NodeID(other)
         return self._id >= other._id
 
     def __hash__(self):
@@ -377,3 +355,25 @@ class NodesRegistry(object):
 
         :param node: an instance of :class:`Node` or a valid node id.
         """
+
+def extract_node_id(node_or_node_id):
+    """Extracts or constructs NodeID from the given object.
+
+    :param node_or_node_id: a valid NodeID or previously initialized
+                            Kaylee Node object.
+    :type node_or_node_id: string, :class:`NodeID` or :class:`Node`
+    :returns: :class:`NodeID` object
+    """
+    no = node_or_node_id
+    if isinstance(no, basestring):
+        return NodeID(node_id=no)
+    elif isinstance(no, NodeID):
+        return no
+    elif isinstance(no, Node):
+        return NodeID(node_id=no.id)
+    else:
+        raise TypeError('node must be an instance of {}, {}, or {} not'
+                        ' {}'.format(basestring.__name__,
+                                     NodeID.__name__,
+                                     Node.__name__,
+                                     type(no).__name__))
