@@ -18,39 +18,36 @@ AUTO_PROJECT_MODE = 0x2
 #: Defines manual project mode (see :attr:`Project.mode`)
 MANUAL_PROJECT_MODE = 0x4
 
+#: Defines the unknown amount of tasks to be solved by a Kaylee
+#: application.
+UNKNOWN_AMOUNT = 0x1
 
 KL_PROJECT_MODE = '__kl_project_mode__'
-KL_PROJECT_SCRIPT = '__kl_project_script__'
+KL_PROJECT_SCRIPT_URL = '__kl_project_script_url__'
 KL_PROJECT_STYLES = '__kl_project_styles__'
 
 
+
 class Project(object):
     """Kaylee Projects abstract base class.
 
-    :param script: The URL of the project's client part (\\*.js file).
+    :param script_url: The URL of the project's client part (\\*.js file).
+    :param mode: defines :attr:`Project.mode <kaylee.Project.mode>`.
     """
-
-    #: Indicates the mode in which project works on the client side.
-    #: Available modes:
-    #:
-    #: * :data:`AUTO_PROJECT_MODE <kaylee.project.AUTO_PROJECT_MODE>`
-    #: * :data:`MANUAL_PROJECT_MODE <kaylee.project.MANUAL_PROJECT_MODE>`
-    #:
-    #: The mode must be set in a project class explicitly e.g.::
-    #:
-    #:    class MyProject(Project):
-    #:        mode = MANUAL_PROJECT_MODE
-    #:
-    #: For detailed description and usage see :ref:`projects_modes`.
     __metaclass__ = ABCMeta
 
-    mode = None
+    def __init__(self, script_url, mode, **kwargs):
+        if mode not in [AUTO_PROJECT_MODE, MANUAL_PROJECT_MODE]:
+            raise ValueError('Wrong project mode: {}'.format(mode))
 
-    def __init__(self, script, **kwargs):
-        # make sure that mode has been defined
-        if self.mode not in [AUTO_PROJECT_MODE, MANUAL_PROJECT_MODE]:
-            raise ValueError('{}.mode is wrong or not defined'.format(
-                    self.__class__.__name__))
+        #: Indicates the mode in which project works on the client side.
+        #: Available modes:
+        #:
+        #: * :data:`AUTO_PROJECT_MODE <kaylee.project.AUTO_PROJECT_MODE>`
+        #: * :data:`MANUAL_PROJECT_MODE <kaylee.project.MANUAL_PROJECT_MODE>`
+        #:
+        #: For detailed description and usage see :ref:`projects_modes`.
+        self.mode = mode
 
         #: A dictionary which contains the configuration passed to the
         #: client-side of the project in :js:func:`pj.init`.
@@ -62,10 +59,11 @@ class Project(object):
         #:           data necessary to properly initialize the client-side
         #:           of the project.
         self.client_config = {
-            KL_PROJECT_SCRIPT : script,
-            KL_PROJECT_MODE   : self.mode,
-            KL_PROJECT_STYLES : kwargs.get('styles', None)
+            KL_PROJECT_SCRIPT_URL: script_url,
+            KL_PROJECT_MODE: self.mode,
+            KL_PROJECT_STYLES: kwargs.get('styles', None),
         }
+
         #: Indicates whether the project was completed.
         self.completed = False
 
@@ -112,3 +110,14 @@ class Project(object):
         :type storage: :class:`PermanentStorage`
         """
         pass
+
+    # @abstractproperty
+    # def progress(self):
+    #     """A tuple of 2 items indicating progress:
+    #     ``(amount_of_tasks_completed, total_amount_of_tasks)``
+
+    #     A negative (:data:`UNKNOWN_AMOUNT`) value of the second item in
+    #     the tuple indicates that the project is not able to calculate the
+    #     total amount of tasks.
+    #     """
+    #     pass
