@@ -10,7 +10,8 @@ import sys
 import unittest
 import logging
 from importlib import import_module
-
+from .helper import (KayleeTest, TestTemporalStorage, TestPermanentStorage,
+                     TestController)
 
 logging.basicConfig(level=logging.CRITICAL)
 log = logging.getLogger(__name__)
@@ -22,10 +23,6 @@ PROJECTS_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)),
 sys.path.insert(0, PROJECTS_DIR)
 
 
-class KayleeTest(unittest.TestCase):
-    """Base class for all Kaylee tests."""
-
-
 def load_tests(test_cases):
     tsuite = unittest.TestSuite()
     for tcase in test_cases:
@@ -113,5 +110,5 @@ class KayleeTestsLoader(unittest.TestLoader):
 
 
 def main():
-    """runs the testsuite as command line application."""
+    """Runs the testsuite as command line application."""
     unittest.main(testLoader = KayleeTestsLoader(), defaultTest = 'default')
