@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-
-
 import json
 
 from kaylee.testsuite import KayleeTest, load_tests
@@ -10,10 +8,10 @@ from datetime import datetime
 
 class KayleeTests(KayleeTest):
     def setUp(self):
-        self.config = __import__('test_config')
+        self.settings = __import__('test_settings')
 
     def test_register_unregister(self):
-        kl = loader.load(self.config)
+        kl = loader.load(self.settings)
         node_json_config = kl.register('127.0.0.1')
         node_config = json.loads(node_json_config)
         self.assertEqual(len(node_config), 3)
@@ -29,16 +27,16 @@ class KayleeTests(KayleeTest):
         self.assertNotIn(nid, kl.registry)
 
     def test_subscribe_unsubscribe(self):
-        kl = loader.load(self.config)
-        app = kl.applications['dummy.1']
+        kl = loader.load(self.settings)
+        app = kl.applications['test.1']
         node_json_config = kl.register('127.0.0.1')
         node_config = json.loads(node_json_config)
         node_id = node_config['node_id']
 
         # test node.subscribe
-        app_json_config = kl.subscribe(node_id, 'dummy.1')
+        app_json_config = kl.subscribe(node_id, 'test.1')
         app_config = json.loads(app_json_config)
-        self.assertEqual(app_config['dummy_key'], 'dummy_value')
+        self.assertEqual(app_config['test_key'], 'test_value')
         node = kl.registry[node_id]
         self.assertEqual(node.controller, app)
         self.assertTrue(0 <= (datetime.now() -
