@@ -1,6 +1,6 @@
 from kaylee.testsuite import KayleeTest, load_tests
 from kaylee.project import Project, AUTO_PROJECT_MODE, MANUAL_PROJECT_MODE
-
+from kaylee.testsuite.helper import NonAbstractProject
 
 class ProjectTests(KayleeTest):
     def setUp(self):
@@ -8,30 +8,27 @@ class ProjectTests(KayleeTest):
 
     def test_project_mode(self):
         # test if initializing Project without a mode raises a ValueError
-        class MyProjectNoMode(Project):
+        class MyProjectNoMode(NonAbstractProject):
             def __init__(self):
-                Project.__init__(self, "/script.js")
+                super(MyProjectNoMode, self).__init__("/script.js")
 
-        self.assertRaises(ValueError, MyProjectNoMode)
+        self.assertRaises(TypeError, MyProjectNoMode)
 
         # -- test with invalid mode
-        class MyProjectInvalidMode(Project):
-            mode = 'abc'
+        class MyProjectInvalidMode(NonAbstractProject):
             def __init__(self):
-                Project.__init__(self, "/script.js")
+                super(MyProjectInvalidMode, self).__init__("/script.js", mode='abc')
         self.assertRaises(ValueError, MyProjectInvalidMode)
 
         # -- test with valid modes
-        class MyProjectWithAutoMode(Project):
-            mode = AUTO_PROJECT_MODE
+        class MyProjectWithAutoMode(NonAbstractProject):
             def __init__(self):
-                Project.__init__(self, "/script.js")
+                super(MyProjectWithAutoMode, self).__init__("/script.js", AUTO_PROJECT_MODE)
         MyProjectWithAutoMode()
 
-        class MyProjectWithManualMode(Project):
-            mode = MANUAL_PROJECT_MODE
+        class MyProjectWithManualMode(NonAbstractProject):
             def __init__(self):
-                Project.__init__(self, "/script.js")
+                super(MyProjectWithManualMode, self).__init__("/script.js", MANUAL_PROJECT_MODE)
         MyProjectWithManualMode()
 
 
