@@ -8,19 +8,24 @@
     :copyright: (c) 2012 by Zaur Nasibov.
     :license: MIT, see LICENSE for more details.
 """
-#pylint: disable-msg=W0402,W0212
+#pylint: disable-msg=W0402,W0212,R0913
 #W0402: 15,0: Uses of a deprecated module 'string'
 #W0212: Access to a protected member _wrapped of a client class
+#R0913: random_string: Too many arguments (7/5)
 ###
 
+import os
 import re
-import importlib
+import sys
 import random
 import string
+import importlib
+import contextlib
+import logging
 from datetime import timedelta
-
 from .errors import KayleeError
 
+
 def parse_timedelta(s):
     try:
         match = parse_timedelta.timeout_regex.match(s)
@@ -108,13 +113,26 @@ class LazyObject(object):
     __dir__ = _new_method_proxy(dir)
 
 
-def random_string(length, **kwargs):
-    alphabet = kwargs.get('alphabet', None)
-    lowercase = kwargs.get('lowercase', True)
-    uppercase = kwargs.get('uppercase', True)
-    digits = kwargs.get('digits', True)
-    extra = kwargs.get('extra', '')
+class DictAsObjectWrapper(object):
+    def __init__(self, **kwargs):
+        for key, val in kwargs.iteritems():
+            setattr(self, key, val)
 
+
+class RecursiveDictAsObjectWrapper(object):
+    def __init__(self, **kwargs):
+        def _update(obj, d):
+            for key, val in d.iteritems():
+                if isinstance(val, dict):
+                    nested_obj = RecursiveDictAsObjectWrapper(**val)
+                    setattr(obj, key, nested_obj)
+                else:
+                    setattr(obj, key, val)
+        _update(self, kwargs)
+
+
+def random_string(length, alphabet=None, lowercase=True, uppercase=True,
+                  digits=True, special=True, extra=''):
     if alphabet is None:
         src = extra
         if lowercase:
@@ -123,22 +141,59 @@ def random_string(length, **kwargs):
             src += string.ascii_uppercase
         if digits:
             src += string.digits
+        if special:
+            src += '!@#$%^&*()_-+=?/><,.|":;`~'
     else:
         src = alphabet
     return ''.join(random.choice(src) for x in xrange(length))
 
 
-def get_secret_key(key = None):
+def get_secret_key(key=None):
     if key is not None:
         return key
     else:
         from kaylee import kl
-        if kl._wrapped is not None:
-            key = kl._config.SECRET_KEY
-            if key is None:
-                raise KayleeError('SECRET_KEY configuration option is not'
-                                  ' defined.')
-            return key
-        else:
+        if kl._wrapped is None:
             raise KayleeError('Cannot locate a valid secret key because '
-                              'Kaylee is not ready yet.')
+                              'Kaylee proxy object has not beet set up.')
+        key = kl.config.SECRET_KEY
+        if key is None:
+            raise KayleeError('SECRET_KEY configuration option is not '
+                              'defined.')
+        return key
+
+
+
+def is_strong_subclass(C, B):
+    """Return whether class C is a subclass (i.e., a derived class) of class B
+    and C is not B.
+    """
+    return issubclass (C, B) and C is not B
+
+
+@contextlib.contextmanager
+def nostdout(stdout=True, stderr=True):
+    savestderr = sys.stderr
+    savestdout = sys.stdout
+    class Devnull(object):
+        def write(self, _):
+            pass
+    if stdout:
+        sys.stdout = Devnull()
+    if stderr:
+        sys.stderr = Devnull()
+    yield
+    sys.stdout = savestdout
+    sys.stderr = savestderr
+
+
+def ensure_dir(path):
+    try:
+        os.makedirs(path)
+    except OSError:
+        if not os.path.isdir(path):
+            raise
+
+def setup_logging(loglevel=logging.INFO):
+    log_format = '%(levelname)s[%(name)s]: %(message)s'
+    logging.basicConfig(level=loglevel, format=log_format)
